==> itools-0.61.2.tar.gz: itools-0.61.2/web/__init__.py <==
# -*- coding: UTF-8 -*-
# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
# Copyright (C) 2007 Sylvain Taverne <sylvain@itaapy.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Import from itools
from access import AccessControl
from context import Context, get_context, set_context, FormError
from context import select_language
from context import WebLogger
from messages import INFO, ERROR, MSG_MISSING_OR_INVALID
from resources import Resource, RootResource
from server import WebServer
from views import BaseView, BaseForm, STLView, STLForm
from webdav import lock_body


__all__ = [
    'AccessControl',
    'WebServer',
    'WebLogger',
    # Context
    'Context',
    'set_context',
    'get_context',
    'select_language',
    # Model
    'Resource',
    'RootResource',
    # View-Controller
    'BaseView',
    'BaseForm',
    'STLView',
    'STLForm',
    # Exceptions
    'FormError',
    # Messages
    'INFO',
    'ERROR',
    'MSG_MISSING_OR_INVALID',
    # Webdav
    'lock_body',
    ]

==> itools-0.62.5.tar.gz: itools-0.62.5/web/__init__.py <==
# -*- coding: UTF-8 -*-
# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
# Copyright (C) 2007 Sylvain Taverne <sylvain@itaapy.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Import from itools
from access import AccessControl
from authentication import generate_password, crypt_password
from authentication import Password, AuthCookie
from context import Context, get_context, set_context
from context import select_language
from context import WebLogger
from exceptions import FormError
from messages import INFO, ERROR, MSG_MISSING_OR_INVALID
from resources import Resource, RootResource
from server import WebServer
from views import BaseView, BaseForm, STLView, STLForm

__all__ = [
    'AccessControl',
    'WebServer',
    'WebLogger',
    # Authentication
    'generate_password',
    'crypt_password',
    'Password',
    'AuthCookie',
    # Context
    'Context',
    'set_context',
    'get_context',
    'select_language',
    # Model
    'Resource',
    'RootResource',
    # View-Controller
    'BaseView',
    'BaseForm',
    'STLView',
    'STLForm',
    # Exceptions
    'FormError',
    # Messages
    'INFO',
    'ERROR',
    'MSG_MISSING_OR_INVALID'
    ]
